wotoValues

package
v0.0.0-...-1fee9d7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	MaximumHistory           = 3
	MultiDbLength            = 10
	MultiDbLastIndex         = 9
	MultiDbFirstIndex        = 0
	MinPostContentTextLength = 1
)
const (
	ResultIdentifier     = "::"
	AdvancedInlinePrefix = "-wh::"
	AdvancedInlineSuffix = "::"
	HelpDataInline       = "help-inline"
	StartDataCreate      = "create"
)

Variables

var (
	// CreatePostHandler is the handler responsible for creating a post,
	// set in `path://src/plugins/postsPlugin/helpers.go`.
	CreatePostHandler handlers.Response
	// HelpHandler is the handler responsible for sending the help message
	// to the user.
	// set in `path://src/plugins/helpPlugin/helpers.go`.
	HelpHandler handlers.Response
)

handlers that need to be shared globally between all plugins

Functions

func GetUniqueIdFromAdvanced

func GetUniqueIdFromAdvanced(query string) string

func IsAdvancedInline

func IsAdvancedInline(data string) bool

Types

type ButtonsUniqueId

type ButtonsUniqueId string

type TextEntitiesGroupId

type TextEntitiesGroupId string

type TextEntitiesUniqueId

type TextEntitiesUniqueId string

type UserPermission

type UserPermission uint8
const (
	PermissionNormalUser UserPermission = iota
	PermissionSpecialUser
	PermissionAdmin
	PermissionDev
	PermissionOwner
)

type WotoCore

type WotoCore struct {
	DbMutex *sync.Mutex
	DB      *gorm.DB
}
var Core *WotoCore = &WotoCore{}

func (*WotoCore) LockDb

func (w *WotoCore) LockDb()

func (*WotoCore) UnlockDb

func (w *WotoCore) UnlockDb()

Jump to